@@ -36,13 +36,13 @@
 
 #include "ebml/EbmlVersion.h"
 
-START_LIBEBML_NAMESPACE
+namespace libebml {
 
-const std::string EbmlCodeVersion = "1.4.0";
+const std::string EbmlCodeVersion = "1.4.3";
 
 // Up to version 1.3.3 this library exported a build date string. As
 // this made the build non-reproducible, replace it by a placeholder to
 // remain API compatible.
 const std::string EbmlCodeDate = "Unknown";
 
-END_LIBEBML_NAMESPACE
+} // namespace libebml
